@@ -6,7 +6,7 @@ from django.conf import settings
 from django.contrib.auth import get_user_model
 from rest_framework_simplejwt.tokens import RefreshToken
 
-from expressmoney.utils import requests
+from expressmoney import requests
 
 User = get_user_model()
 
