@@ -138,6 +138,9 @@ class Point:
         data = self._response.json()
         return data
 
+    def _delete(self):
+        self._response = self._client.delete()
+
     def _post_file(self, file, file_name, type_):
         if self._is_async:
             raise PointError('Post file allowed only for sync request.')
@@ -343,6 +346,11 @@ class ResponseMixin:
         return contract.validated_data
 
 
+class DestroyPointMixin:
+    def destroy(self):
+        self._delete()
+
+
 class UploadFilePointMixin:
     def upload_file(self, file, filename: str, file_type: int):
         self._post_file(file, filename, file_type)
