@@ -38,10 +38,10 @@ def get(service: str, path: str, point_filter: str = None, read_pages: int = 1)
     pages_readed = 0
     next_page_is_exists = True
     while next_page_is_exists and (pages_readed < read_pages or read_pages == 0):
-        path = f'{path}?page={pages_readed + 1}'
+        page_path = f'{path}?page={pages_readed + 1}'
         if point_filter is not None:
-            path = f'{path}&{point_filter}'
-        response = Request(service=service, path=f'{path}&page={pages_readed + 1}').get()
+            page_path = f'{page_path}&{point_filter}'
+        response = Request(service=service, path=page_path).get()
         page_data = response.json().get('results')
         next_page_is_exists = True if response.json().get('next') is not None else False
         if page_data:
